from open_atmos_jupyter_utils import show_plot
from .nondivergent_vector_field_2d import nondivergent_vector_field_2d
